@@ -18,6 +18,9 @@
 // gui merging
 #include <KXMLGUIClient>
 
+// theme support
+#include <KSyntaxHighlighting/Theme>
+
 // widget
 #include <QWidget>
 
@@ -798,6 +801,27 @@ public:
      */
     virtual QList<KTextEditor::AttributeBlock> lineAttributes(int line) = 0;
 
+Q_SIGNALS:
+    /**
+     * This signal is emitted whenever the current view configuration is changed.
+     *
+     * \param view the view which's config has changed
+     *
+     * \since 5.79
+     */
+    void configChanged(KTextEditor::View *view);
+
+public:
+    /**
+     * Get the current active theme of this view.
+     * Might change during runtime, configChanged() will be emitted in that cases.
+     *
+     * \return current active theme
+     *
+     * \since 5.79
+     */
+    KSyntaxHighlighting::Theme theme() const;
+
 private:
     /**
      * private d-pointer, pointing to the internal implementation
